module.exports = {
    docs: [
        {
            type: "doc",
            id: "index",
        },
        {
            type: "doc",
            id: "terminology",
        },
        {
            type: "category",
            label: "Installation",
            items: [
                "installation/index",
                "installation/docker-compose",
                "installation/kubernetes",
                "installation/beta",
                "installation/configuration",
                "installation/reverse-proxy",
                "installation/automated-install",
            ],
        },
        {
            type: "category",
            label: "Providers",
            items: [
                "providers/oauth2",
                "providers/saml",
                {
                    type: "category",
                    label: "Proxy",
                    items: [
                        "providers/proxy/proxy",
                        "providers/proxy/forward_auth",
                    ],
                },
                "providers/ldap",
            ],
        },
        {
            type: "category",
            label: "Outposts",
            items: [
                "outposts/outposts",
                "outposts/embedded/embedded",
                {
                    type: "category",
                    label: "Running and upgrading",
                    items: [
                        "outposts/manual-deploy-docker-compose",
                        "outposts/manual-deploy-kubernetes",
                        "outposts/upgrading",
                    ],
                },
            ],
        },
        {
            type: "category",
            label: "Integrations",
            items: [
                {
                    type: "category",
                    label: "as Source",
                    items: [
                        "integrations/sources/index",
                        "integrations/sources/active-directory/index",
                        "integrations/sources/discord/index",
                        "integrations/sources/github/index",
                        "integrations/sources/google/index",
                        "integrations/sources/ldap/index",
                        "integrations/sources/oauth/index",
                        "integrations/sources/plex/index",
                        "integrations/sources/saml/index",
                    ],
                },
                {
                    type: "category",
                    label: "as Provider",
                    items: [
                        "integrations/services/apache-guacamole/index",
                        "integrations/services/aws/index",
                        "integrations/services/awx-tower/index",
                        "integrations/services/bookstack/index",
                        "integrations/services/gitlab/index",
                        "integrations/services/grafana/index",
                        "integrations/services/harbor/index",
                        "integrations/services/home-assistant/index",
                        "integrations/services/minio/index",
                        "integrations/services/nextcloud/index",
                        "integrations/services/portainer/index",
                        "integrations/services/rancher/index",
                        "integrations/services/sentry/index",
                        "integrations/services/sonarr/index",
                        "integrations/services/tautulli/index",
                        "integrations/services/ubuntu-landscape/index",
                        "integrations/services/veeam-enterprise-manager/index",
                        "integrations/services/vikunja/index",
                        "integrations/services/vmware-vcenter/index",
                        "integrations/services/wekan/index",
                        "integrations/services/wiki-js/index",
                        "integrations/services/wordpress/index",
                        "integrations/services/zabbix/index",
                    ],
                },
            ],
        },
        {
            type: "category",
            label: "Flows",
            items: ["flow/flows", "flow/examples"],
        },
        {
            type: "category",
            label: "Stages",
            items: [
                "flow/stages/authenticator_duo/index",
                "flow/stages/authenticator_static/index",
                "flow/stages/authenticator_totp/index",
                "flow/stages/authenticator_validate/index",
                "flow/stages/authenticator_webauthn/index",
                "flow/stages/captcha/index",
                "flow/stages/deny",
                "flow/stages/email/index",
                "flow/stages/identification/index",
                "flow/stages/invitation/index",
                "flow/stages/password/index",
                "flow/stages/prompt/index",
                "flow/stages/user_delete",
                "flow/stages/user_login",
                "flow/stages/user_logout",
                "flow/stages/user_write",
            ],
        },
        {
            type: "category",
            label: "Policies",
            items: ["policies/index", "policies/expression"],
        },
        {
            type: "category",
            label: "Property Mappings",
            items: ["property-mappings/index", "property-mappings/expression"],
        },
        {
            type: "category",
            label: "Expressions",
            items: [
                {
                    type: "category",
                    label: "Reference",
                    items: ["expressions/reference/user-object"],
                },
            ],
        },
        {
            type: "category",
            label: "Events",
            items: [
                "events/index",
                "events/notifications",
                "events/transports"
            ],
        },
        {
            type: "doc",
            id: "tenants",
        },
        {
            type: "category",
            label: "Maintenance",
            items: ["maintenance/backups/index"],
        },
        {
            type: "category",
            label: "Release Notes",
            items: [
                "releases/v2021.8",
                "releases/v2021.7",
                "releases/v2021.6",
                "releases/v2021.5",
                "releases/v2021.4",
                "releases/v2021.3",
                "releases/v2021.2",
                "releases/v2021.1",
                {
                    type: "category",
                    label: "Previous versions",
                    items: [
                        "releases/v0.14",
                        "releases/v0.13",
                        "releases/v0.12",
                        "releases/v0.11",
                        "releases/v0.10",
                        "releases/v0.9",
                    ],
                },
            ],
        },
        {
            type: "category",
            label: "Troubleshooting",
            items: [
                "troubleshooting/access",
                "troubleshooting/emails",
                "troubleshooting/login",
                "troubleshooting/image_upload_backup",
                "troubleshooting/missing_permission",
            ],
        },
    ],
};
